Re: [Merge] lp:~khurshid-alam/unity-settings-daemon/drop-gnomebg into lp:unity-settings-daemon

2020-02-27 Thread Sebastien Bacher
Build is failing

https://launchpadlibrarian.net/466568903/buildlog_ubuntu-focal-amd64.unity-settings-daemon_15.04.1+19.10.20190921-0ubuntu2_BUILDING.txt.gz

:-(
-- 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/drop-gnomebg/+merge/379825
Your team Unity Settings Daemon Development Team is subscribed to branch 
lp:unity-settings-daemon.

-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop


[Merge] lp:~khurshid-alam/unity-settings-daemon/fix-build-focal into lp:unity-settings-daemon

2020-02-27 Thread Khurshid Alam
Khurshid Alam has proposed merging 
lp:~khurshid-alam/unity-settings-daemon/fix-build-focal into 
lp:unity-settings-daemon.

Commit message:
Move gnome-update-wallpaper-cache into plugins/background so we can link 
libraries properly.

Requested reviews:
  Sebastien Bacher (seb128)

For more details, see:
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/fix-build-focal/+merge/379919
-- 
Your team Unity Settings Daemon Development Team is subscribed to branch 
lp:unity-settings-daemon.
=== modified file 'debian/rules'
--- debian/rules	2018-02-21 21:19:43 +
+++ debian/rules	2020-02-26 19:17:27 +
@@ -10,8 +10,6 @@
 DEB_CONFIGURE_SCRIPT := ./autogen.sh
 DEB_CONFIGURE_EXTRA_FLAGS = --disable-packagekit --enable-ibus --enable-fcitx --enable-network-manager
 
-build/unity-settings-daemon::
-	gcc -o gnome-settings-daemon/gnome-update-wallpaper-cache debian/gnome-update-wallpaper-cache.c `pkg-config --cflags --libs glib-2.0 gdk-3.0 gdk-x11-3.0 gio-2.0 gnome-desktop-3.0`
 
 # don't configure with --libdir, but move the files manually, because
 # other files in /usr/lib/ should not change
@@ -21,7 +19,6 @@
 		debian/tmp/usr/lib/$(DEB_HOST_MULTIARCH)
 
 install/unity-settings-daemon::
-	/usr/bin/install -c gnome-settings-daemon/gnome-update-wallpaper-cache 'debian/tmp/usr/lib/unity-settings-daemon'
 	install -m 644 -D debian/unity-settings-daemon.user-session.upstart debian/unity-settings-daemon/usr/share/upstart/sessions/unity-settings-daemon.conf
 	install -m 644 -D debian/unity-settings-daemon.user-session.desktop debian/unity-settings-daemon/usr/share/upstart/xdg/autostart/unity-settings-daemon.desktop
 
@@ -34,5 +31,3 @@
 
 common-binary-post-install-arch:: list-missing
 
-clean::
-	rm -f gnome-settings-daemon/gnome-update-wallpaper-cache

=== modified file 'plugins/background/Makefile.am'
--- plugins/background/Makefile.am	2020-02-23 15:03:25 +
+++ plugins/background/Makefile.am	2020-02-26 19:17:27 +
@@ -29,6 +29,29 @@
 	$(BACKGROUND_LIBS)\
 	$(NULL)
 
+libexec_PROGRAMS += gnome-update-wallpaper-cache
+
+gnome_update_wallpaper_cache_SOURCES =		\
+	gnome-update-wallpaper-cache.c		\
+	$(NULL)
+
+gnome_update_wallpaper_cache_CPPFLAGS = \
+	-I$(top_srcdir)/gnome-settings-daemon		\
+	-DGNOME_SETTINGS_LOCALEDIR=\""$(datadir)/locale"\" \
+	$(AM_CPPFLAGS)
+
+gnome_update_wallpaper_cache_CFLAGS = \
+	$(SETTINGS_PLUGIN_CFLAGS)	\
+	$(BACKGROUND_CFLAGS)		\
+	$(AM_CFLAGS)
+
+gnome_update_wallpaper_cache_LDADD =\
+	$(top_builddir)/gnome-settings-daemon/libgsd.la	\
+	$(top_builddir)/gnome-settings-daemon/libunity-settings-daemon.la	\
+	$(SETTINGS_PLUGIN_LIBS)\
+	$(BACKGROUND_LIBS)\
+	$(NULL)
+
 plugin_LTLIBRARIES = \
 	libbackground.la		\
 	$(NULL)

=== added file 'plugins/background/gnome-update-wallpaper-cache.c'
--- plugins/background/gnome-update-wallpaper-cache.c	1970-01-01 00:00:00 +
+++ plugins/background/gnome-update-wallpaper-cache.c	2020-02-26 19:17:27 +
@@ -0,0 +1,72 @@
+/*
+ * Copyright (C) 2010 Canonical, Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see .
+ *
+ * Authored by Didier Roche 
+ * 
+ * Bug: https://bugs.launchpad.net/bugs/530024
+ */
+
+#include "config.h"
+
+#include 
+#include 
+
+#include "gsd-bg.h"
+
+static GOptionEntry entries[] =
+{
+  { NULL }
+};
+
+main (int argc, char *argv[])
+{
+GOptionContext *context = NULL;
+GError *error = NULL;
+
+GdkScreen *screen;
+GdkRectangle rect;
+GsdBG *bg;
+GSettings *settings;
+GdkPixbuf *pixbuf;
+
+gdk_init (, );
+
+context = g_option_context_new ("- refresh wallpaper cache");
+g_option_context_add_main_entries (context, entries, NULL);
+if (!g_option_context_parse (context, , , )) {
+g_printerr ("option parsing failed: %s\n", error->message);
+g_option_context_free(context);
+g_error_free (error);
+return (1);
+}
+if (context)
+g_option_context_free (context);
+
+/* cache only the first monitor */
+screen = gdk_screen_get_default ();
+gdk_screen_get_monitor_geometry (screen, 0, );
+
+bg = gsd_bg_new ();
+settings = g_settings_new ("org.gnome.desktop.background");
+gsd_bg_load_from_preferences (bg, settings);
+
+pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, rect.width, rect.height);
+gsd_bg_draw (bg, pixbuf, screen, FALSE);
+
+g_object_unref 

Re: [Merge] ~3v1n0/ubuntu/+source/gnome-shell:ubuntu/master into ~ubuntu-desktop/ubuntu/+source/gnome-shell:ubuntu/master

2020-02-27 Thread Treviño
GJS version we depend on is at 
https://code.launchpad.net/~3v1n0/ubuntu/+source/gjs/+git/gjs/+ref/ubuntu/master
-- 
https://code.launchpad.net/~3v1n0/ubuntu/+source/gnome-shell/+git/gnome-shell/+merge/379843
Your team Ubuntu Desktop is requested to review the proposed merge of 
~3v1n0/ubuntu/+source/gnome-shell:ubuntu/master into 
~ubuntu-desktop/ubuntu/+source/gnome-shell:ubuntu/master.

-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop


[Merge] lp:~khurshid-alam/unity-settings-daemon/fix-build-focal into lp:unity-settings-daemon

2020-02-27 Thread Sebastien Bacher
The proposal to merge lp:~khurshid-alam/unity-settings-daemon/fix-build-focal 
into lp:unity-settings-daemon has been updated.

Status: Needs review => Approved

For more details, see:
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/fix-build-focal/+merge/379919
-- 
Your team Unity Settings Daemon Development Team is subscribed to branch 
lp:unity-settings-daemon.

-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop


Re: [Merge] lp:~khurshid-alam/unity-settings-daemon/drop-gnomebg into lp:unity-settings-daemon

2020-02-27 Thread Khurshid Alam
Since this is merged I fixed the build here. 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/fix-build-focal/+merge/379919

It is compiling locally for me along with unity and unity-control-center.

But in proposed after new llib11 we are getting errors because of 
https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=952589 which is already fixed 
in debian. 
-- 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/drop-gnomebg/+merge/379825
Your team Unity Settings Daemon Development Team is subscribed to branch 
lp:unity-settings-daemon.

-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop


Re: [Merge] lp:~khurshid-alam/unity-settings-daemon/fix-build-focal into lp:unity-settings-daemon

2020-02-27 Thread Sebastien Bacher
Review: Approve

thanks!
-- 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/fix-build-focal/+merge/379919
Your team Unity Settings Daemon Development Team is subscribed to branch 
lp:unity-settings-daemon.

-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop


[Merge] lp:~khurshid-alam/unity-control-center/drop-gnomebg into lp:unity-control-center

2020-02-27 Thread Khurshid Alam
Khurshid Alam has proposed merging 
lp:~khurshid-alam/unity-control-center/drop-gnomebg into 
lp:unity-control-center.

Commit message:
* Drop libgnome-desktop for background drawing. Use libunity-settings-daemon 
instead. LP: #1863584

* Update version to 20.04 LTS

Requested reviews:
  Sebastien Bacher (seb128)
Related bugs:
  Bug #1863584 in unity-settings-daemon (Ubuntu): "Drop gnombg for background 
drawing"
  https://bugs.launchpad.net/ubuntu/+source/unity-settings-daemon/+bug/1863584

For more details, see:
https://code.launchpad.net/~khurshid-alam/unity-control-center/drop-gnomebg/+merge/379826

Note it must compiled against new unity-settings-daemon in 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/drop-gnomebg/+merge/379825
-- 
Your team Unity Control Center development team is subscribed to branch 
lp:unity-control-center.
=== modified file 'configure.ac'
--- configure.ac	2019-05-01 13:16:51 +
+++ configure.ac	2020-02-25 16:05:10 +
@@ -139,7 +139,7 @@
 PKG_CHECK_MODULES(SHELL, $COMMON_MODULES libgnome-menu-3.0 gio-unix-2.0 x11
   polkit-gobject-1 >= $POLKIT_REQUIRED_VERSION)
 PKG_CHECK_MODULES(APPEARANCE_PANEL, $COMMON_MODULES libxml-2.0 gnome-desktop-3.0
-  gdk-pixbuf-2.0 >= $GDKPIXBUF_REQUIRED_VERSION)
+  gdk-pixbuf-2.0 >= $GDKPIXBUF_REQUIRED_VERSION libunity-settings-daemon)
 PKG_CHECK_MODULES(DATETIME_PANEL, $COMMON_MODULES timezonemap geonames
   polkit-gobject-1 >= $POLKIT_REQUIRED_VERSION)
 PKG_CHECK_MODULES(DISPLAY_PANEL, $COMMON_MODULES libunity-settings-daemon x11)

=== modified file 'debian/rules'
--- debian/rules	2019-09-02 14:41:58 +
+++ debian/rules	2020-02-25 16:05:10 +
@@ -18,6 +18,6 @@
 DEB_DH_MAKESHLIBS_ARGS_libunity-control-center1 += -- -c4
 
 binary-post-install/unity-control-center::
-	./panels/info/logo-generator --logo panels/info/UbuntuLogoBlank.png --text "ubuntu 19.10" --output debian/unity-control-center/usr/share/unity-control-center/ui/UbuntuLogo.png
+	./panels/info/logo-generator --logo panels/info/UbuntuLogoBlank.png --text "ubuntu 20.04 LTS" --output debian/unity-control-center/usr/share/unity-control-center/ui/UbuntuLogo.png
 
 common-binary-post-install-arch:: list-missing

=== modified file 'panels/appearance/cc-appearance-item.c'
--- panels/appearance/cc-appearance-item.c	2018-02-16 13:02:27 +
+++ panels/appearance/cc-appearance-item.c	2020-02-25 16:05:10 +
@@ -26,7 +26,7 @@
 #include 
 #include 
 
-#include 
+#include 
 #include 
 
 #include "cc-appearance-item.h"
@@ -51,7 +51,7 @@
 CcAppearanceItemFlags flags;
 
 /* internal */
-GnomeBG *bg;
+GsdBG *bg;
 char*mime_type;
 int  width;
 int  height;
@@ -105,7 +105,7 @@
 		filename = g_file_get_path (file);
 		g_object_unref (file);
 
-		gnome_bg_set_filename (item->priv->bg, filename);
+		gsd_bg_set_filename (item->priv->bg, filename);
 		g_free (filename);
 	}
 
@@ -116,8 +116,8 @@
 gdk_rgba_parse (, item->priv->secondary_color);
 }
 
-gnome_bg_set_rgba (item->priv->bg, item->priv->shading, , );
-gnome_bg_set_placement (item->priv->bg, item->priv->placement);
+gsd_bg_set_rgba (item->priv->bg, item->priv->shading, , );
+gsd_bg_set_placement (item->priv->bg, item->priv->placement);
 }
 
 
@@ -130,7 +130,7 @@
 
 changes = FALSE;
 if (item->priv->bg != NULL) {
-changes = gnome_bg_changes_with_time (item->priv->bg);
+changes = gsd_bg_changes_with_time (item->priv->bg);
 }
 return changes;
 }
@@ -144,7 +144,7 @@
 	if (item->priv->uri == NULL) {
 		item->priv->size = g_strdup ("");
 	} else {
-		if (gnome_bg_has_multiple_sizes (item->priv->bg) || gnome_bg_changes_with_time (item->priv->bg)) {
+		if (gsd_bg_has_multiple_sizes (item->priv->bg) || gsd_bg_changes_with_time (item->priv->bg)) {
 			item->priv->size = g_strdup (_("multiple sizes"));
 		} else {
 			/* translators: 100 × 100px
@@ -157,14 +157,14 @@
 }
 
 static GdkPixbuf *
-render_at_size (GnomeBG *bg,
+render_at_size (GsdBG *bg,
 gint width,
 gint height)
 {
 GdkPixbuf *pixbuf;
 
 pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, width, height);
-gnome_bg_draw (bg, pixbuf, gdk_screen_get_default (), FALSE);
+gsd_bg_draw (bg, pixbuf, gdk_screen_get_default (), FALSE);
 
 return pixbuf;
 }
@@ -189,21 +189,21 @@
 /* FIXME: this doesn't play nice with slideshow stepping at all,
  * because it will always render the current slideshow frame, which
  * might not be what we want.
  * We're lacking an API to draw a high-res GnomeBG manually choosing
  * the slideshow frame though, so we can't do much 
@@ -189,21 +189,21 @@
  * because it will always render the current slideshow frame, which
  * might not be what we want.
- * We're lacking an API to draw a high-res GnomeBG manually choosing
+ * We're lacking an API to draw a high-res GsdBG manually choosing
  * the slideshow frame though, so we can't do much 


Re: [Merge] lp:~khurshid-alam/unity-settings-daemon/drop-gnomebg into lp:unity-settings-daemon

2020-02-27 Thread Sebastien Bacher
Review: Approve

Thanks!
-- 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/drop-gnomebg/+merge/379825
Your team Unity Settings Daemon Development Team is subscribed to branch 
lp:unity-settings-daemon.

-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop